@@ -104,10 +104,12 @@ class hexagon_grid:
     
     def __init__(self,
                  data, 
-                 spacing
+                 spacing,
+                 area_threshold:float = None
                  ):
         self.data = data
         self.spacing = spacing
+        self.area_threshold = area_threshold
         if isinstance(data, str):
             gdf = gpd.read_file(self.data)
         elif isinstance(data, gpd.GeoDataFrame):
@@ -179,10 +181,22 @@ class hexagon_grid:
                                 gpd.overlay(gdf.explode().reset_index().drop(['level_0', 'level_1'], axis = 1),
                                             datax, how='intersection'),
                                 how = 'union')[['geometry']].copy()
-        area_threshold = (spacing*spacing)*0.33
-        disolve_hexa = dissolve_polygon(final_hexa, area_threshold).geosolution
-        check_topology(disolve_hexa)
-        self.geosolution = disolve_hexa
+        if self.area_threshold == None:
+            area_threshold = (spacing*spacing)*0.33
+            disolve_hexa = dissolve_polygon(final_hexa, area_threshold).geosolution
+            hexagon = gpd.overlay(data, disolve_hexa, how = 'union')
+            df = hexagon.explode().reset_index().drop(['level_0', 'level_1'], axis = 1)
+            check_topology(df)
+            self.geosolution = df
+        elif 0.0 >= self.area_threshold >= 0.8 and self.area_threshold != None:
+            raise ValueError("You shouldn't cross the upper/lower limit of area threshold.\nThreshold should be 0.0> area_threshold>=0.8")
+        else:
+            area_thres = (spacing*spacing)*self.area_threshold
+            disolve_hexa = dissolve_polygon(final_hexa, area_thres).geosolution
+            hexagon = gpd.overlay(data, disolve_hexa, how = 'union')
+            df = hexagon.explode().reset_index().drop(['level_0', 'level_1'], axis = 1)
+            check_topology(df)
+            self.geosolution = df
 
 class merge_shapefile:
     
